This takes as input an intervention dataframe (int.table). The dataframe should have as columns 'Day' number, new intervention metric (either New.Re or New.Double.Time) and the number of days that the intervention is smoothed over (Days.to.Reach.New.Re).

create.beta.vec(int.table, gamma, usedouble)

Arguments

int.table

Dataframe with columns: Day, New.Re (or New.Double.Time), and Days.to.Reach.New.Re

gamma

Numeric.

usedouble

Boolean. TRUE if doubling time is used as the metric.

Value

Vector of beta values to use in the SEIR simulation.

Details

The function also takes as input a gamma value a flag for whether doubling time or is used as the metric (usedouble).

It returns a vector of beta values that correspond with the intervention dataframe.