find.curr.estimates: Find 'Current' Information

Description Usage Arguments Details Value

View source: R/helper.R

Description

This function first runs the simulation on Day 1, with one person exposed.

Usage

1
2
find.curr.estimates(model, N, beta.vector, num.days, num.actual, metric,
  start.exp, params)

Arguments

model

String, model to use (either M0, M1, M2)

N

Numeric, number of people in the area.

beta.vector

Vector of numerics, should be the same length as num.days.

num.days

Numeric. Number of days to simulate.

num.actual

Numeric. Number to match on the curve.

metric

tring. Metric to use for matching (currently only compatible with 'Cases' and 'Hospitalizations').

start.exp

Starting number of exposures to simulate.

params

Parameters to input into the SEIR function.

Details

Based on the metric provided, it finds the day on the curve that corresponds to the metric. For example, if the user specifies the number of actual hospitalizations is 100 (num.actual = 100, metric = 'Hospitalizations'), then it finds the day on the curve that corresponds to 100 hospitalizations.

It then returns a list with that day as well as the number susceptible, exposed, infected, and recovered on that day.

Value

List with the day number match as well as counts for susceptible, exposed, infected and recovered.


lemdt/CovidShinyModel documentation built on May 10, 2020, 1:54 p.m.