This function takes in as inputs a vector of new hospitalizations per day and runs the Markov simulation using this.

runMarkov(new.g.vec, trans.mat)

Arguments

new.g.vec

Vector of numerics, which describe the number of new hospitalizations per day.

trans.mat

Matrix. For Markov simulation.

Value

Dataframe, with counts of each state.

Details

It returns a dataframe with the number of people in the general hospital (G.state), non-ventilated ICU (ICU.state), ventilated ICU (V.state), discharged (DCH.state), and dead (M.state).