Description Usage Arguments Details Value
Runs the SEIR model using the Model 1 specification. https://docs.google.com/document/d/1CEoKQ1pD1x4yH7GzR3mViWtfVG-4Do8ViZUd4z_t9Ts/edit?usp=sharing
1 | SEIR_M1(S0, E0, I0, R0, beta.vector, num.days, influx, params)
|
S0 |
Numeric. Initial number of susceptible individuals. |
E0 |
Numeric. Initial number of exposed individuals. |
I0 |
Numeric. Initial number of infected individuals. |
R0 |
Numeric. Initial number of recovered individuals. |
beta.vector |
Vector, of beta values to use in the simulation on each day. Should have the same length as num.days. |
num.days |
Numeric. Number of days to run the simulation. |
influx |
List. This is hash consisting of a 'day' and an 'influx' number, meant to represent an influx of infections into the region |
params |
List. This should contain the parameters for running the SEIR, including: - Sigma - Gamma - hosp.delay.time: time between infection and hospitalization - hosp.rate: percent hospitalized out of those infected - hosp.los: hospital length of stay if not admitted to ICU - icu.delay.time: time between hospitalization and ICU admission - icu.rate: percent ICU admitted among those hospitalized - icu.los : average ICU length of stay if not ventilated - vent.delay.time: time between ICU ventilation and being put on a ventilator - vent.rate: percent ventilated among those ICU admitted - vent.los: average time on a ventilator |
The simulation ignores births and deaths.
Dataframe, with susceptible counts, exposed counts, infected counts, hospitalization numbers, and recovery numbers.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.