SEIR_M2: Run SEIR model for Model 2

Description Usage Arguments Details Value

View source: R/models.R

Description

Runs the SEIR model, incorporating the separate hospitalization Markov component. More about the technique is here: https://drive.google.com/file/d/157yB7O62xyJps2_HUtAelqsQ8e9feTj_/view?usp=sharing https://sites.me.ucsb.edu/~moehlis/APC514/tutorials/tutorial_seasonal/node4.html

Usage

1
SEIR_M2(S0, E0, I0, R0, beta.vector, num.days, influx, params)

Arguments

S0

Numeric. Initial number of susceptible individuals.

E0

Numeric. Initial number of exposed individuals.

I0

Numeric. Initial number of infected individuals.

R0

Numeric. Initial number of recovered individuals.

beta.vector

Vector, of beta values to use in the simulation on each day. Should have the same length as num.days.

num.days

Numeric. Number of days to run the simulation.

influx

List. This is hash consisting of a 'day' and an 'influx' number, meant to represent an influx of infections into the region

params

List. This should contain the parameters for running the SEIR, including sigma, gamma.r, gamma.h, hosp.rate, and the transition probabilities (p.g_g, p.g_icu, p.g_d)

Details

The simulation ignores births and deaths.

Value

Dataframe, with susceptible counts, exposed counts, infected counts, hospitalization numbers, recovery numbers, and death numbers.


lemdt/CovidShinyModel documentation built on May 10, 2020, 1:54 p.m.