Description Usage Arguments Details Value
This takes as input an intervention dataframe (int.table). The dataframe should have as columns 'Day' number, new intervention metric (either New.Re or New.Double.Time) and the number of days that the intervention is smoothed over (Days.to.Reach.New.Re).
1 | create.beta.vec(int.table, gamma, usedouble)
|
int.table |
Dataframe with columns: Day, New.Re (or New.Double.Time), and Days.to.Reach.New.Re |
gamma |
Numeric. |
usedouble |
Boolean. TRUE if doubling time is used as the metric. |
The function also takes as input a gamma value a flag for whether doubling time or is used as the metric (usedouble).
It returns a vector of beta values that correspond with the intervention dataframe.
Vector of beta values to use in the SEIR simulation.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.