Description Usage Arguments Details Value
This function first runs the simulation on Day 1, with one person exposed.
1 2 | find.curr.estimates(model, N, beta.vector, num.days, num.actual, metric,
start.exp, params)
|
model |
String, model to use (either M0, M1, M2) |
N |
Numeric, number of people in the area. |
beta.vector |
Vector of numerics, should be the same length as num.days. |
num.days |
Numeric. Number of days to simulate. |
num.actual |
Numeric. Number to match on the curve. |
metric |
tring. Metric to use for matching (currently only compatible with 'Cases' and 'Hospitalizations'). |
start.exp |
Starting number of exposures to simulate. |
params |
Parameters to input into the SEIR function. |
Based on the metric provided, it finds the day on the curve that corresponds to the metric. For example, if the user specifies the number of actual hospitalizations is 100 (num.actual = 100, metric = 'Hospitalizations'), then it finds the day on the curve that corresponds to 100 hospitalizations.
It then returns a list with that day as well as the number susceptible, exposed, infected, and recovered on that day.
List with the day number match as well as counts for susceptible, exposed, infected and recovered.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.