runMarkov: Run Markov Simulation

Description Usage Arguments Details Value

View source: R/models.R

Description

This function takes in as inputs a vector of new hospitalizations per day and runs the Markov simulation using this.

Usage

1
runMarkov(new.g.vec, trans.mat)

Arguments

new.g.vec

Vector of numerics, which describe the number of new hospitalizations per day.

trans.mat

Matrix. For Markov simulation.

Details

It returns a dataframe with the number of people in the general hospital (G.state), non-ventilated ICU (ICU.state), ventilated ICU (V.state), discharged (DCH.state), and dead (M.state).

Value

Dataframe, with counts of each state.


lemdt/CovidShinyModel documentation built on May 10, 2020, 1:54 p.m.